# 0.2.1
Add Asset Types endpoint 

# 0.2.0
Extended assets endpoint functionality

# 0.1.0
Delete capability for asset endpoints

# 0.0.8
Release to Azure devops

# 0.0.6
Addition of tbump

# 0.0.5
Added an endpoint for assets
